.. BurnMan documentation master file, created by
   sphinx-quickstart on Mon Apr 21 16:47:58 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pyeq3: an equation, curve and surface fitting library
=====================================================

.. toctree::
   :maxdepth: 4
   :glob:

   introduction
   model_list
   zreferences
